@@ -7,6 +7,7 @@ extract_tracks = function(data) {
   } else {
     output = lapply(points, process_points)
     output = lapply(seq_along(output), function(i){output[[i]][["Segment ID"]] = i;return(output[[i]])}) #nolint
+    names(output) = vapply(tracks, extract_feature, NA_character_, "name")
   }
   return(output)
 }
@@ -22,6 +23,16 @@ extract_routes = function(data) {
   return(output)
 }
 
+extract_waypoints = function(data) {
+  points = rvest::html_nodes(data, "wpt")
+  if (length(points) == 0) {
+    output = generate_empty()
+  } else {
+    output = process_waypoints(points)
+  }
+  return(output)
+}
+
 generate_empty = function() {
   empty = data.frame("Elevation" = logical()
                    , "Time" = logical()
@@ -68,6 +79,25 @@ extract_extensions = function(points) {
   return(output)
 }
 
+process_waypoints = function(points) {
+  attrs = rvest::html_attrs(points)
+  df = do.call(rbind, attrs)
+  ele = as.numeric(extract_feature(points, "ele"))
+  time = lubridate::as_datetime(extract_feature(points, "time"))
+  lat = as.numeric(extract_feature(points, "lat"))
+  lon = as.numeric(extract_feature(points, "lon"))
+  name = extract_feature(points, "name")
+  desc = extract_feature(points, "desc")
+  output = data.frame("Elevation" = ele
+                      , "Time" = time
+                      , "Latitude" = lat
+                      , "Longitude" = lon
+                      , "Name" = name
+                      , "Description" = desc
+                      , stringsAsFactors = FALSE)
+  return(output)
+}
+
 coalesce = function(...) {
   Reduce(function(x, y) {
     i = which(is.na(x))
